package com.example.androidskuska

import android.os.Bundle
import android.text.Html
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.core.text.HtmlCompat
import androidx.navigation.fragment.findNavController
import com.example.androidskuska.api.CountryResponse
import com.example.androidskuska.databinding.FragmentDetailBinding
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


/**
 * A simple [Fragment] subclass as the second destination in the navigation.
 */
class DetailFragment : Fragment() {

    private var _binding: FragmentDetailBinding? = null

    // This property is only valid between onCreateView and
    // onDestroyView.
    private val binding get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {

        _binding = FragmentDetailBinding.inflate(inflater, container, false)
        return binding.root

    }

    //vytvaranie fragmentu, ked je pripraveny fragment na zobrazenie
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        //zavola sa funkcia find z API
        App.api.find(arguments?.getString("name"))
            .enqueue(object : Callback<List<CountryResponse>> {

                override fun onResponse(
                    call: Call<List<CountryResponse>>?,
                    response: Response<List<CountryResponse>>?
                ) {
                    //osetrovanie chyb
                    if (response?.body() == null) {
                        Toast.makeText(activity, R.string.error_find, Toast.LENGTH_LONG).show()
                        findNavController().navigateUp()
                        return
                    }
                    val countries = response.body()
                    //osetrovanie chyb ked je krajin viacej
                    if (countries.size > 1) {
                        Toast.makeText(activity, R.string.error_many, Toast.LENGTH_LONG).show()
                        findNavController().navigateUp()
                        return
                    }
                    //vybuildi text
                    val country = countries.first()
                    val builder = StringBuilder()
                    builder.append("<b>"+ getString(R.string.label_name) +"</b>")
                    builder.append(country.name.official)
                    builder.append("<br>")
                    builder.append("<b>"+ getString(R.string.label_capital) +"</b>")
                    builder.append(country.capital.first())
                    builder.append("<br>")
                    builder.append("<b>"+ getString(R.string.label_languages) +"</b><br>")
                    country.languages.forEach {
                        builder.append(it.value)
                        builder.append("<br>")
                    }
                    builder.append("<b>"+ getString(R.string.label_currencies) +"</b><br>")
                    country.currencies.forEach {
                        builder.append(it.value.name)
                        builder.append("<br>")
                    }
                    binding.textList.text = HtmlCompat.fromHtml(builder.toString(), HtmlCompat.FROM_HTML_MODE_LEGACY)
                }
                //zavola sa ked sa zlyha komunikacia s API napr. ked nepojde internet
                override fun onFailure(call: Call<List<CountryResponse>>?, t: Throwable?) {
                    println(t?.message)
                    Toast.makeText(activity, R.string.error_communication, Toast.LENGTH_LONG).show()
                }

            })
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}