package com.example.androidskuska

import android.annotation.SuppressLint
import android.app.AlertDialog
import android.os.Bundle
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.core.os.bundleOf
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.LinearLayoutManager
import com.example.androidskuska.databinding.FragmentListBinding


/**
 * A simple [Fragment] subclass as the default destination in the navigation.
 */
class ListFragment : Fragment() {

    private var _binding: FragmentListBinding? = null

    // This property is only valid between onCreateView and
    // onDestroyView.
    private lateinit var adapter: CountryAdapter
    private val binding get() = _binding!!

    override fun onCreateView(
            inflater: LayoutInflater, container: ViewGroup?,
            savedInstanceState: Bundle?
    ): View {

        _binding = FragmentListBinding.inflate(inflater, container, false)
        return binding.root

    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        binding.buttonAdd.setOnClickListener {
            //nastaveny pocuvadlo na klikanie
            findNavController().navigate(R.id.action_ListFragment_to_FormFragment)
        }
        //prvky budu pod sebou
        val manager = LinearLayoutManager(context)
        binding.recyclerList.layoutManager = manager
        //oddelovacia ciara
        val divider = DividerItemDecoration(binding.recyclerList.context, manager.orientation)
        binding.recyclerList.addItemDecoration(divider)
        //nastaveny adapter k Recycleru
        val countries = App.db.getCountryDao().getAll().toMutableList()
        adapter = CountryAdapter(countries, onClick, onLongClick)
        binding.recyclerList.adapter = adapter


    }
    //nastavenie kliku
    private val onClick: (Country)->Unit = {
        findNavController().navigate(R.id.action_ListFragment_to_DetailFragment, bundleOf("name" to it.name))
    }
    // nastavenie podrzania
    @SuppressLint("NotifyDataSetChanged")
    private val onLongClick: (Country)->Unit = {
        AlertDialog.Builder(activity).setTitle(R.string.dialogue_title).setPositiveButton(R.string.yes) { _, _ ->
            App.db.getCountryDao().delete(it)
            adapter.countries.remove(it)
            adapter.notifyDataSetChanged()
        }.setNegativeButton(R.string.no) { dialogue, _ ->
            dialogue.dismiss()
        }.show()
    }
    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}